@@ -1,8 +1,10 @@
 from pathlib import Path
 from unittest import TestCase, skipIf
 import doc_safer
+import io
 import platform
 from readme_renderer import rst
+from test import get_help
 
 README_TEXT = Path(doc_safer.README_FILE).read_text()
 
@@ -14,5 +16,16 @@ class TestDoc(TestCase):
         assert actual.rstrip() == README_TEXT.rstrip()
 
     def test_rendering(self):
-        actual = rst.render(README_TEXT)
-        assert actual is not None
+        out = io.StringIO()
+        actual = rst.render(README_TEXT, out)
+        if actual is None:
+            print('Rendering error!')
+            print(out.getvalue())
+            assert False
+
+    def test_help(self):
+        with open(get_help.HELP_FILE) as fp:
+            actual = fp.read()
+
+        expected = get_help.get_help()
+        assert expected == actual
